@@ -155,6 +155,7 @@ class FluxAgent:
         self.extensions.add_method(self.disconnect_shell)
         self.extensions.add_method(self.get_state)
         self.extensions.add_method(self.get_directory_hashes)
+        self.extensions.add_method(self.enable_registrar_fileserver)
         # self.extensions.add_method(self.run_entrypoint)
 
     async def get_auth_provider(self):
@@ -454,6 +455,9 @@ class FluxAgent:
             "registrar_enabled": self.enable_registrar,
         }
 
+    def enable_registrar_fileserver(self):
+        self.registrar.ready_to_serve = True
+
     async def load_plugins(self, directory: str):
         p = Path(directory)
 
